package com.laszlomarket;

import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;

import java.util.List;

/**
 * Stores information related to an <code>Product</code>
 * within the Struts framework.  Also provides validation on the Product.
 * 
 * @author Norman Klein
 *
 */

public class ProductForm extends ActionForm {
    private Long id;
	private String title;
	private String image;
    private String sku;
	private Double price;
	private Integer quantity;

    List product = null;

	/**
	* validate() ensures the user's product is valid and returns the appropriate
	* <code>ActionErrors</code>
	* object, if any errors are generated.
	* 
	* @return <code>ActionErrors</code> A collection of errors generated by validation process.
	* 
	 */
	public ActionErrors validate(ActionMapping mapping, HttpServletRequest request) {

		/*
		 * Create new ActionErrors object to hold any errors we discover
		 * upon validation of the form's fields.
		 * 
		 */
		ActionErrors errors = new ActionErrors();

        String action = request.getParameter("action");

		if ("add".equals(action)) {
		   if (id == null || id.intValue() < 0) {
		      errors.add(ActionErrors.GLOBAL_ERROR, new ActionError("errors.required", "id"));
              return errors;
           }
       	   if (quantity == null || quantity.intValue() <= 0) {
              errors.add(ActionErrors.GLOBAL_ERROR, new ActionError("errors.badquantity"));
              return errors;
		   }
		}

        else if ("delete".equals(action)) {
		   if (id == null || id.intValue() < 0) {
		      errors.add(ActionErrors.GLOBAL_ERROR, new ActionError("errors.required", "id"));
              return errors;
           }
        }

		else if ("get".equals(action)) {
		   if (id == null || id.intValue() < 0) {
		      errors.add(ActionErrors.GLOBAL_ERROR, new ActionError("errors.required", "id"));
              return errors;
           }
		}

		else if ("update".equals(action)) {
		   if (id == null || id.intValue() < 0) {
		      errors.add(ActionErrors.GLOBAL_ERROR, new ActionError("errors.required", "id"));
			  return errors;
           }
           if (quantity == null || quantity.intValue() <= 0) {
              errors.add(ActionErrors.GLOBAL_ERROR, new ActionError("errors.badquantity"));
              return errors;
           }
        }

		else if ("list".equals(action)) return errors;
  
        else {
           errors.add(ActionErrors.GLOBAL_ERROR, new ActionError("errors.unknownaction"));
           return errors;
        }
        

		return errors;
	}

	/**
	 * Clears the object prior to each request. 
	 */
	public void reset(ActionMapping mapping, HttpServletRequest request)
	{
		this.clear();
	}

	/**
	 * getId() retrieves <code>ID</code> field.
     */
	public Long getId() { return id; }

	/**
	 * getTitle() retrieves <code>title</code> field.
	 */
	public String getTitle() { return title; }

	/**
	 * getImage() retrieves <code>image</code> field.
	 */
	public String getImage() { return image; }

	/**
	 * getSku() retrieves <code>sku</code> field.
	 */
	public String getSku() { return sku; }

	/**
	 * getQuantity() retrieves <code>quantity</code> field.
	 */
	public Integer getQuantity() { return quantity; }

	/**
	 * getPrice() retrieves <code>price</code> field.
	 */
	public Double getPrice() { return price; }

	/**
	 * getProduct() retrieves <code>product</code> field.
	 */
    public List getProduct() { return product; }

	/**
	 * setId() retrieves <code>ID</code> field.
	 */
	public void setId(Long id) { this.id = id; }

	/**
	 * Sets <code>title</code> field.
	 */
	public void setTitle(String title) { this.title = title; }

	/**
	 * Sets <code>image</code> field.
	 */
	public void setImage(String image) { this.image = image; }

	/**
	 * Sets <code>sku</code> field.
	 */
	public void setSku(String sku) { this.sku = sku; }

	/**
	 * Sets <code>price</code> field.
	 */
	public void setPrice(Double price) { this.price = price; }

	/**
	 * Sets <code>quantity</code> field.
	 */
	public void setQuantity(Integer quantity) { this.quantity = quantity; }

	/**
	 * Sets <code>product</code> field.
	 */
	public void setProduct(List product) { this.product = product; }


	/**
	 * clear() sets all the object's fields to <code>null</code>.
	 */
	public void clear() {
        this.id   = null;
		this.title = null;
		this.image = null;
		this.price = null;
        this.sku   = null;
		this.quantity = null;
	}

}

